__author__ = 'soroosh'

import click

from ci import probe

@click.command("probe")
@click.option('--host', required=True, help='Host name which you want to ping.')
@click.option('--port', required=True, help='Port number which you want to ping.')
@click.option('--retries', default=10, help='Number of retries. default: 10')
@click.option('--interval', default=1, help='Time interval between probes (In second). default 1 second')
def probe_cmd(host, port, retries, interval):
    probe.try_connect(host, port, retries, interval)


def main(): probe_cmd()

if __name__ == '__main__':
    main()


from time import sleep

__author__ = 'soroosh'

import click
import socket


def connect(hostname, port):
    sock = socket.socket()
    sock.connect((hostname, int(port)))


def try_connect(hostname, port, retries=10, time_interval=1):
    for i in range(0, retries):
        try:
            connect(hostname, port)
            return
        except:
            sleep(time_interval)
            pass

    raise Exception("Could not connect to {0}:{1} after {2} retries".format(hostname, port, retries))


if __name__ == "__main__":
    try_connect('localhost', 9042)


__author__ = 'soroosh'

from distutils.core import setup
import os.path
import setuptools

def read_version(package):
    data = {}
    with open(os.path.join(package, '__init__.py'), 'r') as fd:
        exec(fd.read(), data)
    return data['__version__']

CONSOLE_SCRIPTS = ['octopus = ci.cli:main']
setup(
    name='octopus-ci',
    version=read_version('ci'),
    description='Bunch of commands to help continuous integration',
    author='Soroosh Sarabadani',
    author_email='soroosh.sarabadani@zalando.de',
    url='https://github.com/psycho-ir/octopus-ci',
    keywords=['ci tools, probe port'],
    packages=setuptools.find_packages(exclude=['tests', 'tests.*']),
    install_requires=['click'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
    entry_points={'console_scripts': CONSOLE_SCRIPTS},
)